diff graal/com.oracle.max.cri/src/com/sun/cri/bytecode/BytecodeSwitch.java @ 4142:bc8527f3071c

Adjust code base to new level of warnings.
author Thomas Wuerthinger <thomas.wuerthinger@oracle.com>
date Sun, 18 Dec 2011 05:24:06 +0100
parents e233f5660da4
children
line wrap: on
line diff
--- a/graal/com.oracle.max.cri/src/com/sun/cri/bytecode/BytecodeSwitch.java	Sun Dec 18 05:23:52 2011 +0100
+++ b/graal/com.oracle.max.cri/src/com/sun/cri/bytecode/BytecodeSwitch.java	Sun Dec 18 05:24:06 2011 +0100
@@ -127,13 +127,13 @@
 
     /**
      * Reads the signed value at given bytecode index.
      * @param bci the start index of the value to retrieve
      * @return the signed, 4-byte value in the bytecode array starting at {@code bci}
      */
-    protected int readWord(int bci) {
+    protected int readWord(int readBci) {
         if (code != null) {
-            return Bytes.beS4(code, bci);
+            return Bytes.beS4(code, readBci);
         }
-        return stream.readInt(bci);
+        return stream.readInt(readBci);
     }
 }
@@ -127,13 +127,13 @@
     /**
      * Reads the signed value at given bytecode index.
-     * @param bci the start index of the value to retrieve
+     * @param readBci the start index of the value to retrieve
      * @return the signed, 4-byte value in the bytecode array starting at {@code bci}
      */